#include <iostream> // Entrada / Salida
#include <vector> // Arreglo Dinamico
#include <queue> // Cola

using namespace std; // Importante

struct Graph{ // Estructura Grafo  

    vector<vector<int>> edges; // Lista de Adyacencia
    vector<bool> visited; // Arreglo de Visitados 
    vector<int> super; // Componente / Supernodo
    bool bi; // Bidireccional?
    int n; // Numero de Nodos

    Graph(int N, int Bi = true): // Constructor
        n(N), bi(Bi), edges(N), visited(N), super(N) {}

    void addEdge(int u, int v){ // Agregar Aristas
        if(bi) edges[v].push_back(u); // Solo bidireccionales 
        edges[u].push_back(v); 
    }

    void Dfs(int u, int s){ //Busqueda en Profundidad
        visited[u] = true; // Marcamos al nodo como visitado
        super[u] = s; // Le decimos al nodo a que componente pertence
        for(int v : edges[u]) // Reccorremos la lista de adyacencia del nodo
            if(!visited[v]) Dfs(v, s);  // Visitamos los nodos adyacentes 
                                        // que no han sido visitados para 
                                        // anadirlos a la componente
    }

    void Bfs(int u, int s){ //Busqueda en Amplitud
        queue<int> q; q.push(u); // Creamos la cola y agregamos al nodo de inicio
        while(!q.empty()){ // La busqueda se ejecuta mientras la cola no este vacia
            int u = q.front(); // Obtenemos el frente de la cola (nodo actual)
            visited[u] = true; // Marcamos el nodo como visitado
            super[u] = s; // Le decimos al nodo a que componente pertenece
            q.pop(); // Extraemos el frente de la cola
            for(int v : edges[u]) // Recorremos la lista de adyacencia del nodo
                if(!visited[v]) q.push(v);  // Agregamos los adyacentes no vistados 
                                            //a la cola de proceso
        }
    }

    int countComponents(){ // Flood Fill
        int components = 0; // Conteo de componentes
        for(int u = 0; u < n; u++) // Marcamos todos los nodos como no visitados
            visited[u] = false;
        for(int u = 0; u < n; u++){ // Recorremos todos los nodos en busca 
                                    // de componentes nuevas (no visitados)
            if(visited[u]) continue; // Si el nodo actual fue visitado lo ignoramos
            // No fue visitado, encontramos una nueva componente
            Dfs(u, components++);   // Lanzamos una busqueda desde el nodo 
                                    //para explorar la nueva componente y la contamos
            //Bfs(u, components++); // Cualquiera de las dos busquedas, pero no ambas
        }
        return components; // Devolvemos el numero de componentes
    }

};

int main(){ //Programa Principal
    int m,n,u,v; // Numero de aristas, numero de nodos, extremo de la arista, otro extremo
    Graph *g; // Apuntador a un grafo
    cin >> n >> m, // Leemos numero de nodos y aristas
    g = new Graph(n); // Creamos el grafo 
    for(int i = 0; i < m; i++)  // Inicia lectura de aristas
        cin >> u >> v,          // Leemos los extremos de la arista (1-indexados)
        g->addEdge(--u, --v);   // Agregamos la arista (0-indexada)
                                // Termina lecturas de aristas
    cout << g->countComponents() << '\n'; // Imprimimos el numero de componentes 
    for(int k : g->super)   // Recorremos la lista de super-nodos 
        cout << k << ' ';   // Imprimimos el super-nodo de cada nodo
    cout << '\n'; // Salto de linea
    delete g; // Liberamos memoria 
    return 0; //Fin del Programa
}

